<?php
/**
 * Default theme options.
 *
 * @package University_Hub
 */

if ( ! function_exists( 'university_hub_get_default_theme_options' ) ) :

	/**
	 * Get default theme options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Default theme options.
	 */
	function university_hub_get_default_theme_options() {

		$defaults = array();

		// Header.
		$defaults['show_title']                 = true;
		$defaults['show_tagline']               = true;
		$defaults['show_ticker']                = true;
		$defaults['ticker_title']               = esc_html__( 'News:', 'university-hub-pro' );
		$defaults['ticker_category']            = 0;
		$defaults['ticker_number']              = 3;
		$defaults['contact_number']             = '234-235-5678';
		$defaults['contact_email']              = 'demo@wenthemes.com';
		$defaults['contact_address_1']          = esc_html__( 'Street 124, Lalitpur', 'university-hub-pro' );
		$defaults['contact_address_2']          = esc_html__( 'Kathmandu, Nepal', 'university-hub-pro' );
		$defaults['show_social_in_header']      = false;
		$defaults['enable_sticky_primary_menu'] = false;
		$defaults['search_in_header']           = true;

		// Layout.
		$defaults['site_layout']             = 'fluid';
		$defaults['global_layout']           = 'right-sidebar';
		$defaults['archive_layout']          = 'excerpt';
		$defaults['archive_image']           = 'large';
		$defaults['archive_image_alignment'] = 'center';
		$defaults['single_image']            = 'large';
		$defaults['single_image_alignment']  = 'center';

		// Home Page.
		$defaults['home_content_status'] = true;

		// Pagination.
		$defaults['pagination_type'] = 'numeric';

		// Content Meta.
		$defaults['show_meta_author']     = true;
		$defaults['show_meta_categories'] = true;
		$defaults['show_meta_tags']       = true;
		$defaults['show_meta_comment']    = true;

		// Footer.
		$defaults['copyright_text']        = esc_html__( 'Copyright &copy; [the-year] [the-site-link]. All rights reserved.', 'university-hub-pro' );
		$defaults['powered_by_text']       = esc_html__( 'University Hub Pro by ', 'university-hub-pro' ) . '<a target="_blank" rel="designer" href="http://wenthemes.com/">WEN Themes</a>';
		$defaults['reset_footer_content']  = false;
		$defaults['show_social_in_footer'] = false;
		$defaults['go_to_top']             = true;

		// Blog.
		$defaults['excerpt_length']     = 40;
		$defaults['read_more_text']     = esc_html__( 'Read more', 'university-hub-pro' );
		$defaults['exclude_categories'] = '';

		// Author Bio.
		$defaults['author_bio_in_single']           = true;
		$defaults['author_bio_show_recent_posts']   = false;
		$defaults['author_bio_recent_posts_number'] = 3;

		// Breadcrumb.
		$defaults['breadcrumb_type'] = 'simple';

		// Homepage Sections.
		$defaults['homepage_sections'] = array( 'call-to-action', 'news-and-events', 'latest-news' );

		// Homepage Call To Action.
		$defaults['cta_title']               = esc_html__( 'Join Our University', 'university-hub-pro' );
		$defaults['cta_description']         = esc_html__( 'Every undergraduate student is eligible to receive a fellowship of up to $10,000 for a summer internship or faculty-mentored research project. Find your opportunity, make your case for how it fits your academic plans, and we will help fund it.', 'university-hub-pro' );
		$defaults['cta_primary_button_text'] = esc_html__( 'Learn More', 'university-hub-pro' );
		$defaults['cta_primary_button_url']  = '#';
		$defaults['cta_secondary_button_text'] = esc_html__( 'Online Tour', 'university-hub-pro' );
		$defaults['cta_secondary_button_url']  = '#';

		// Homepage News and Events.
		$defaults['news_and_events_ntitle']    = esc_html__( 'News', 'university-hub-pro' );
		$defaults['news_and_events_nnumber']   = 2;
		$defaults['news_and_events_ncategory'] = 0;
		$defaults['news_and_events_etitle']    = esc_html__( 'Events', 'university-hub-pro' );
		$defaults['news_and_events_enumber']   = 4;
		$defaults['news_and_events_ecategory'] = 0;

		// Homepage Services.
		$defaults['services_title']  = esc_html__( 'Services', 'university-hub-pro' );
		$defaults['services_number'] = 6;
		$defaults['services_column'] = 3;

		// Homepage Featured Blocks.
		$defaults['featured_blocks_number'] = 3;
		$defaults['featured_blocks_column'] = 3;

		// Homepage Latest News.
		$defaults['latest_news_title']          = esc_html__( 'Latest News', 'university-hub-pro' );
		$defaults['latest_news_layout']         = 1;
		$defaults['latest_news_category']       = 0;
		$defaults['latest_news_number']         = 4;
		$defaults['latest_news_column']         = 4;
		$defaults['latest_news_featured_image'] = 'university-hub-thumb';
		$defaults['latest_news_excerpt_length'] = 20;

		// Homepage Testimonials.
		$defaults['testimonials_title']            = esc_html__( 'Testimonials', 'university-hub-pro' );
		$defaults['testimonials_category']         = 0;
		$defaults['testimonials_number']           = 4;
		$defaults['testimonials_background_image'] = '';

		// Homepage Team.
		$defaults['team_title']    = esc_html__( 'Our Team', 'university-hub-pro' );
		$defaults['team_category'] = 0;
		$defaults['team_number']   = 4;
		$defaults['team_column']   = 4;

		// Font.
		$font_keys = university_hub_get_font_family_theme_settings_options();
		if ( ! empty( $font_keys ) ) {
			foreach ( $font_keys as $k => $v ) {
			  $defaults[ $k ]  = $v['default'];
			}
		}
		$defaults['reset_font_settings'] = false;

		// Slider Options.
		$defaults['featured_slider_status']              = 'home-page';
		$defaults['featured_slider_transition_effect']   = 'fadeout';
		$defaults['featured_slider_transition_delay']    = 3;
		$defaults['featured_slider_transition_duration'] = 1;
		$defaults['featured_slider_enable_caption']      = true;
		$defaults['featured_slider_enable_arrow']        = true;
		$defaults['featured_slider_enable_pager']        = true;
		$defaults['featured_slider_enable_autoplay']     = true;
		$defaults['featured_slider_type']                = 'demo-slider';
		$defaults['featured_slider_number']              = 3;
		$defaults['featured_slider_category']            = '';
		$defaults['featured_slider_tag']                 = '';
		$defaults['featured_slider_read_more_text']      = esc_html__( 'Read More', 'university-hub-pro' );

		// Color.
		$colors = university_hub_get_default_colors();
		if ( ! empty( $colors ) ) {
		  foreach ( $colors as $key => $val ) {
		    $defaults[ $key ] = $val;
		  }
		}

		// Pass through filter.
		$defaults = apply_filters( 'university_hub_filter_default_theme_options', $defaults );
		return $defaults;
	}

endif;
